| IP-Addresses   | Hostnames                             | Ports                                                                                                                                                               | Services                                                                                                                                                           | Banners                                                                                                                                                                                                                                                                                                                                                                                                                                                     | OS      |
|:---------------|:--------------------------------------|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------|:------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|:--------|
| 192.168.56.10  | kingslanding.sevenkingdoms.local      | 53/tcp<br>80/tcp<br>88/tcp<br>135/tcp<br>139/tcp<br>389/tcp<br>445/tcp<br>464/tcp<br>593/tcp<br>636/tcp<br>3268/tcp<br>3269/tcp<br>3389/tcp<br>5985/tcp<br>5986/tcp | domain<br>http<br>kerberos-sec<br>msrpc<br>netbios-ssn<br>ldap<br>microsoft-ds<br>kpasswd5<br>ncacn\_http<br>ldap<br>ldap<br>ldap<br>ms-wbt-server<br>http<br>http | Simple DNS Plus<br>Microsoft IIS httpd/10.0<br>Microsoft Windows Kerberos<br>Microsoft Windows RPC<br>Microsoft Windows netbios-ssn<br>Microsoft Windows Active Directory LDAP<br><br><br>Microsoft Windows RPC over HTTP/1.0<br>Microsoft Windows Active Directory LDAP<br>Microsoft Windows Active Directory LDAP<br>Microsoft Windows Active Directory LDAP<br>Microsoft Terminal Services<br>Microsoft HTTPAPI httpd/2.0<br>Microsoft HTTPAPI httpd/2.0 | windows |
| 192.168.56.11  | winterfell.north.sevenkingdoms.local  | 53/tcp<br>88/tcp<br>135/tcp<br>139/tcp<br>389/tcp<br>445/tcp<br>464/tcp<br>593/tcp<br>636/tcp<br>3268/tcp<br>3269/tcp<br>3389/tcp<br>5985/tcp<br>5986/tcp           | domain<br>kerberos-sec<br>msrpc<br>netbios-ssn<br>ldap<br>microsoft-ds<br>kpasswd5<br>ncacn\_http<br>ldap<br>ldap<br>ldap<br>ms-wbt-server<br>http<br>http         | Simple DNS Plus<br>Microsoft Windows Kerberos<br>Microsoft Windows RPC<br>Microsoft Windows netbios-ssn<br>Microsoft Windows Active Directory LDAP<br><br><br>Microsoft Windows RPC over HTTP/1.0<br>Microsoft Windows Active Directory LDAP<br>Microsoft Windows Active Directory LDAP<br>Microsoft Windows Active Directory LDAP<br>Microsoft Terminal Services<br>Microsoft HTTPAPI httpd/2.0<br>Microsoft HTTPAPI httpd/2.0                             | windows |
| 192.168.56.22  | castelblack.north.sevenkingdoms.local | 80/tcp<br>135/tcp<br>139/tcp<br>445/tcp<br>1433/tcp<br>3389/tcp<br>5985/tcp<br>5986/tcp                                                                             | http<br>msrpc<br>netbios-ssn<br>microsoft-ds<br>ms-sql-s<br>ms-wbt-server<br>http<br>http                                                                          | Microsoft IIS httpd/10.0<br>Microsoft Windows RPC<br>Microsoft Windows netbios-ssn<br><br>Microsoft SQL Server 2019/15.00.2000.00; RTM<br>Microsoft Terminal Services<br>Microsoft HTTPAPI httpd/2.0<br>Microsoft HTTPAPI httpd/2.0                                                                                                                                                                                                                         | windows |